@@ -26,7 +26,7 @@ import java.text.NumberFormat;
 
 public class LabelDistributionEvaluator extends TransducerEvaluator {
 
-  private static final Logger logger = MalletLogger.getLogger (InstanceAccuracyEvaluator.class.getName());
+  private static final Logger logger = MalletLogger.getLogger (LabelDistributionEvaluator.class.getName());
   
   public LabelDistributionEvaluator (InstanceList[] instanceLists, String[] descriptions) {
     super (instanceLists, descriptions);
